@@ -1,13 +1,12 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2014-2015 Rumma & Ko Ltd
+# Copyright 2014-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-import logging
-logger = logging.getLogger(__name__)
+import logging ; logger = logging.getLogger(__name__)
 
 import datetime
 
-from unipath import Path
+from pathlib import Path
 
 from lino.api import rt
 
@@ -163,8 +162,8 @@ def objects():
             title = a2[1]
 
             import lino
-            fn = Path(lino.__file__).parent.parent.child('docs', 'tickets')
-            fn = fn.child(num + '.rst')
+            fn = Path(lino.__file__).parent.parent / 'docs' / 'tickets'
+            fn = fn / num + '.rst'
             kw = dict()
             kw.update(created=datetime.datetime.fromtimestamp(fn.ctime()))
             kw.update(modified=datetime.datetime.fromtimestamp(fn.mtime()))
